+++
title = "Multiple authors"
author = ["Foo Bar", "Toto Kumar", "Zulu", "Ágota Kristóf"]
tags = ["front-matter", "author"]
draft = false
+++

This post has multiple authors. In Org, multiple authors are added
comma-separated.
